function z = cnv(x, h)
% Convolution of signal x by finite impulse response h.
% Covariance form.
%
% Syntax:	z = cnv(x, h)
%
%		x: Input signal. Continuous or point sequence.
%		h: Impulse response. Continuous data.
%
%		z: Convolved sequence. Continuous data.
%

%	TESTS AND INITIALIZATION

%	Test: Sampling periods

Te_x = x(2, 1) - x(1, 1);
Te_h = h(2, 1) - h(1, 1);
if abs(Te_x - Te_h) >= 10*eps
  fprintf('ERROR: Check sampling periods of signals\n')
  return
end

%	Initialization of z

M = size(x); N = M(1);		% Number of samples in x
M = size(h); p = M(1);		% Number of samples in h
P = N - p + 1;			% Number of samples in z

if P <= 0			% Test on the sizes of signals
    fprintf('ERROR: Check sizes of signals\n')
    RETURN
end

z = zeros(P, 2);		% Initialization of z
% z(:, 1) = (x(1, 1)+h(p, 1):Te_x:x(N, 1)+h(1, 1))';
z(:, 1) = Te_x * (0:P-1)' + x(1, 1)+h(p, 1);
% z(end, 1)-(x(N, 1)+h(1, 1))

				% Support region

%	CONVOLUTION

for i = 1:P
    z(i, 2) = h(:, 2)' * x(i+p-1:-1:i, 2);
end

return
