function cplot(X1, X2, X3, X4)
% cplot plots one to four continuous signals. The types of lines are
% the following:	First signal: 	solid
%			Second signal: 	dashed
%			Third signal:	dotted
%			Fourth signal:	dash-dot
% Omitted signals are not plotted.
%
% Syntax: cplot(X1, X2, X3, X4)
%
%	  X1: First signal
%	  X2: Second signal
%	  X3: Third signal
%	  X4: Fourth signal
%

%	TESTS AND INITIALIZATION

Nbsig = 0;			% Total number of signals

if exist('X1') == 1		% First signal defined?
    Nbsig = Nbsig + 1;		% Increment number of signals
    [N1, aux] = size(X1);	% Size of signal

    if aux < 2			% Test data format
	fprintf('\nERROR "cplot": Wrong format for signal X1.\n')
	return
    end

    Mi_X(Nbsig) = X1(1, 1);	% Minimum value of X axis
    Ma_X(Nbsig) = X1(N1, 1);	% Maximum value of X axis
    Mi_Y(Nbsig) = min(X1(:, 2));% Minimum value of Y axis
    Ma_Y(Nbsig) = max(X1(:, 2));% Maximum value of Y axis
end

if exist('X2') == 1		% Second signal defined?
    Nbsig = Nbsig + 1;		% Increment number of signals
    [N2, aux] = size(X2);	% Size of signal

    if aux < 2			% Test data format
	fprintf('\nERROR "cplot": Wrong format for signal X2.\n')
	return
    end

    Mi_X(Nbsig) = X2(1, 1);	% Minimum value of X axis
    Ma_X(Nbsig) = X2(N2, 1);	% Maximum value of X axis
    Mi_Y(Nbsig) = min(X2(:, 2));% Minimum value of Y axis
    Ma_Y(Nbsig) = max(X2(:, 2));% Maximum value of Y axis
end

if exist('X3') == 1		% Third signal defined?
    Nbsig = Nbsig + 1;		% Increment number of signals
    [N3, aux] = size(X3);	% Size of signal

    if aux < 2			% Test data format
	fprintf('\nERROR "cplot": Wrong format for signal X3.\n')
	return
    end

    Mi_X(Nbsig) = X3(1, 1);	% Minimum value of X axis
    Ma_X(Nbsig) = X3(N3, 1);	% Maximum value of X axis
    Mi_Y(Nbsig) = min(X3(:, 2));% Minimum value of Y axis
    Ma_Y(Nbsig) = max(X3(:, 2));% Maximum value of Y axis
end

if exist('X4') == 1		% Fourth signal defined?
    Nbsig = Nbsig + 1;		% Increment number of signals
    [N4, aux] = size(X4);	% Size of signal

    if aux < 2			% Test data format
	fprintf('\nERROR "cplot": Wrong format for signal X4.\n')
	return
    end

    Mi_X(Nbsig) = X4(1, 1);	% Minimum value of X axis
    Ma_X(Nbsig) = X4(N4, 1);	% Maximum value of X axis
    Mi_Y(Nbsig) = min(X4(:, 2));% Minimum value of Y axis
    Ma_Y(Nbsig) = max(X4(:, 2));% Maximum value of Y axis
end

%	test

if Nbsig == 0			% No signal specified
    fprintf('\nERROR "cplot": How can I plot no signal?\n')
    return
end

%	PLOT

%	Scaling

m_X = min(Mi_X);		% Global minimum on the x axis
M_X = max(Ma_X);		% Global maximum on the x axis
m_Y = min(Mi_Y);		% Global minimum on the y axis
M_Y = max(Ma_Y);		% Global maximum on the Y axis

% clf				%
% axis('auto');			% Preparation du trace pour obtenir
% plot([m_X M_X], [m_Y M_Y], 'k');% des echelles adequates
% axis(axis);			% Axis scaling

%	Plot

hold on

if exist('X1') == 1		% If X1 specified
    plot(X1(:, 1), X1(:, 2), '-');
end				%plot

if exist('X2') == 1		% If X2 specified
    plot(X2(:, 1), X2(:, 2), '--');
end				%plot

if exist('X3') == 1		% If X3 specified
    plot(X3(:, 1), X3(:, 2), ':');
end				%plot

if exist('X4') == 1		% If X4 specified
    plot(X4(:, 1), X4(:, 2), '-.');
end				%plot

hold off
set(gca, 'Xlim', [m_X M_X], 'Ylim', [m_Y M_Y])
grid

return





