function x = dl2l1(z, h, Lbd, delta, Niter)
% Dconvolution L2L1, algorithme de Geman et Yang
%
% Syntax :      x = dl2l1(z, h, Lbd, delta, Niter)
%		z: Observed sequence. Continuous data.
%		h: Impulse response. Continuous data.
%		Lbd: Regularization parameter.
%               delta: Scale parameter of the penalty function
%               Niter: Number of iterations (default: 100)
%              

%	TESTS

%	Sampling periods

Te_z = z(2, 1) - z(1, 1);
Te_h = h(2, 1) - h(1, 1);
if abs(Te_z - Te_h) >= 10*eps
    fprintf('\nERROR "dl2l1": Check sampling frequencies of signals\n')
    return
end

M = size(z); P = M(1);		% Number of samples in z
M = size(h); p = M(1);		% Number of samples in h
N = P + p - 1;			% Number of samples in x

%	INITIALISATION

fprintf('Initializing internal variables...\n')

if exist('Niter') ~= 1
  Niter = 100;
end


x = zeros(N, 2);		% Initialization of x
x(:,1) = (z(1,1)-h(p, 1):Te_z:z(P, 1)-h(1, 1))';

H = toeplitz([h(p,2); zeros(P-1, 1)], [fliplr(h(:, 2)'), zeros(1, P-1)]);
  
alpha = 1.99 * delta;
A = inv(H'*H + Lbd / (2*alpha) * eye(N));
vec = H'*z(:, 2);
xaux = x(:, 2);

% Itrations

fprintf('Computing the solution...\n')

for iter = 1:Niter
  u = xaux - alpha * (xaux ./ sqrt(delta^2 + xaux.^2));
  xaux = A * (vec + Lbd/(2*alpha) * u);
end

fprintf('Done!\n')

L = 0;
x(:, 2) = xaux;

return



